Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/gnu/dist/toolchain Use the now-standard BFD_RELOC_ARM_JUMP_S...



details:   https://anonhg.NetBSD.org/src/rev/71b8bc1f8ef0
branches:  trunk
changeset: 503111:71b8bc1f8ef0
user:      tv <tv%NetBSD.org@localhost>
date:      Wed Jan 31 19:35:11 2001 +0000

description:
Use the now-standard BFD_RELOC_ARM_JUMP_SLOT name in lieu of
BFD_RELOC_ARM_JMPSLOT.

diffstat:

 gnu/dist/toolchain/bfd/aout-arm32.c    |  8 ++++----
 gnu/dist/toolchain/gas/config/tc-arm.c |  2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diffs (51 lines):

diff -r 61bc1303671a -r 71b8bc1f8ef0 gnu/dist/toolchain/gas/config/tc-arm.c
--- a/gnu/dist/toolchain/gas/config/tc-arm.c    Wed Jan 31 18:44:07 2001 +0000
+++ b/gnu/dist/toolchain/gas/config/tc-arm.c    Wed Jan 31 19:35:11 2001 +0000
@@ -6008,7 +6008,7 @@
     case BFD_RELOC_ARM_PCREL_BRANCH:
       if (pic_code)
        {
-         code = BFD_RELOC_ARM_JMPSLOT;
+         code = BFD_RELOC_ARM_JUMP_SLOT;
          break;
        }
     case BFD_RELOC_RVA:      



Home | Main Index | Thread Index | Old Index
diff -r 61bc1303671a -r 71b8bc1f8ef0 gnu/dist/toolchain/bfd/aout-arm32.c
--- a/gnu/dist/toolchain/bfd/aout-arm32.c       Wed Jan 31 18:44:07 2001 +0000
+++ b/gnu/dist/toolchain/bfd/aout-arm32.c       Wed Jan 31 19:35:11 2001 +0000
@@ -97,7 +97,7 @@
         0x00000fff, 0x00000fff, false),
   HOWTO (18, 0, 2, 32, false, 0, complain_overflow_bitfield, 0, "GOT32", true,
         0xffffffff, 0xffffffff, false),
-  HOWTO (19, 0, 2, 26, true, 0, complain_overflow_bitfield, MY(fix_pcrel_26), "JMPSLOT", true,
+  HOWTO (19, 0, 2, 26, true, 0, complain_overflow_bitfield, MY(fix_pcrel_26), "JUMP_SLOT", true,
         0x00ffffff, 0x00ffffff, true),
 
   {-1},
@@ -165,7 +165,7 @@
   index = r_length + 4 * r_pcrel_done + 8 * r_neg + 16 * r_pic;
   if (index == 3)
     *r_pcrel = 1;        
-  if (index == 19)     /* jmpslot */
+  if (index == 19)     /* jump_slot */
     *r_pcrel = 1;        
 FPRINTF((stderr, " index=%d name=%s\n", index, (MY(howto_table) + index)->name));
   return MY(howto_table) + index;
@@ -261,7 +261,7 @@
       ASTD (BFD_RELOC_ARM_GOT12, 17);
       ASTD (BFD_RELOC_ARM_GOT32, 18);
       ASTD (BFD_RELOC_ARM_GOTPC, 22);
-      ASTD (BFD_RELOC_ARM_JMPSLOT, 19);
+      ASTD (BFD_RELOC_ARM_JUMP_SLOT, 19);
     default: return (CONST struct reloc_howto_struct *) 0;
     }
 }
@@ -423,7 +423,7 @@
   if (g->howto->type >= 16)
     r_pic = 1;
 
   /* jmpslot (branch with pic set) - treat like a branch */
   if (g->howto->type == 19) {
       r_length = 3;
       r_pcrel = 0;
@@ -423,7 +423,7 @@
     r_pic = 1;
 
-  /* jmpslot (branch with pic set) - treat like a branch */
+  /* jump_slot (branch with pic set) - treat like a branch */
   if (g->howto->type == 19) {
       r_length = 3;